.. _tutorials:

*********
Tutorials
*********
This section presents tutorials to help you get started with FHI-aims in SEAMM and
explore its capabilities. There are more general tutorials in the main SEAMM
documentation which cover getting started with SEAMM, and the basics of using the
SEAMM GUI and Dashboard. If you are not familiar with SEAMM, you should go through
at least the first couple SEAMM tutorials before starting these tutorials.

.. toctree::
    :maxdepth: 1
    :titlesonly:
    :glob:

    tutorial_1


